@@ -24,10 +24,10 @@
 #' @include GenerativeTemplate.R
 #' @export DispersalTemplate
 
-DispersalTemplate <- R6Class("DispersalTemplate",
+DispersalTemplate <- R6Class(
+  "DispersalTemplate",
   inherit = GenerativeTemplate,
   public = list(
-
     ## Attributes ##
 
     #' @field attached A list of dynamically attached attributes (name-value pairs).
@@ -40,7 +40,6 @@ DispersalTemplate <- R6Class("DispersalTemplate",
   ), # end public
 
   private = list(
-
     ## Attributes ##
     # .description            [inherited]
     # .inputs                 [inherited]
@@ -67,9 +66,9 @@ DispersalTemplate <- R6Class("DispersalTemplate",
 
   # Active binding accessors for private attributes (above) #
   active = list(
-
     #' @field description A brief description of what the generator generates.
-    description = function(value) { # inherited
+    description = function(value) {
+      # inherited
       if (missing(value)) {
         super$description
       } else {
@@ -78,7 +77,8 @@ DispersalTemplate <- R6Class("DispersalTemplate",
     },
 
     #' @field inputs An array of input attribute names for the generator.
-    inputs = function(value) { # inherited
+    inputs = function(value) {
+      # inherited
       if (missing(value)) {
         super$inputs
       } else {
@@ -87,7 +87,8 @@ DispersalTemplate <- R6Class("DispersalTemplate",
     },
 
     #' @field outputs An array of output attribute names for the generator.
-    outputs = function(value) { # inherited
+    outputs = function(value) {
+      # inherited
       if (missing(value)) {
         super$outputs
       } else {
@@ -96,7 +97,8 @@ DispersalTemplate <- R6Class("DispersalTemplate",
     },
 
     #' @field file_templates A nested list of file template attributes.
-    file_templates = function(value) { # inherited
+    file_templates = function(value) {
+      # inherited
       if (missing(value)) {
         super$file_templates
       } else {
@@ -105,7 +107,8 @@ DispersalTemplate <- R6Class("DispersalTemplate",
     },
 
     #' @field function_templates A nested list of function template attributes.
-    function_templates = function(value) { # inherited
+    function_templates = function(value) {
+      # inherited
       if (missing(value)) {
         super$function_templates
       } else {
@@ -114,7 +117,8 @@ DispersalTemplate <- R6Class("DispersalTemplate",
     },
 
     #' @field distribution_templates A list of distribution template attributes.
-    distribution_templates = function(value) { # inherited
+    distribution_templates = function(value) {
+      # inherited
       if (missing(value)) {
         super$distribution_templates
       } else {
@@ -123,7 +127,8 @@ DispersalTemplate <- R6Class("DispersalTemplate",
     },
 
     #' @field uses_correlations A boolean to indicate that a \code{\link{SpatialCorrelation}} (or inherited class) object is used for generating correlated random deviates.
-    uses_correlations = function(value) { # inherited
+    uses_correlations = function(value) {
+      # inherited
       if (missing(value)) {
         super$uses_correlations
       } else {
@@ -132,7 +137,8 @@ DispersalTemplate <- R6Class("DispersalTemplate",
     },
 
     #' @field spatial_correlation A \code{\link{SpatialCorrelation}} (or inherited class) object for generating correlated random deviates.
-    spatial_correlation = function(value) { # inherited
+    spatial_correlation = function(value) {
+      # inherited
       if (missing(value)) {
         super$spatial_correlation
       } else {
@@ -141,7 +147,8 @@ DispersalTemplate <- R6Class("DispersalTemplate",
     },
 
     #' @field temporal_correlation Absolute correlation coefficient between simulation time steps for all grid cells (0-1; default = 1).
-    temporal_correlation = function(value) { # inherited
+    temporal_correlation = function(value) {
+      # inherited
       if (missing(value)) {
         super$temporal_correlation
       } else {
@@ -150,7 +157,8 @@ DispersalTemplate <- R6Class("DispersalTemplate",
     },
 
     #' @field time_steps Number of simulation time steps.
-    time_steps = function(value) { # inherited
+    time_steps = function(value) {
+      # inherited
       if (missing(value)) {
         super$time_steps
       } else {
@@ -159,7 +167,8 @@ DispersalTemplate <- R6Class("DispersalTemplate",
     },
 
     #' @field decimals Number of decimal places applied to generated data outputs (default: NULL = no rounding).
-    decimals = function(value) { # inherited
+    decimals = function(value) {
+      # inherited
       if (missing(value)) {
         super$decimals
       } else {
@@ -168,7 +177,8 @@ DispersalTemplate <- R6Class("DispersalTemplate",
     },
 
     #' @field occupancy_mask Optional binary mask array (matrix), data frame, or raster (stack) for generated (time-series) data outputs.
-    occupancy_mask = function(value) { # inherited
+    occupancy_mask = function(value) {
+      # inherited
       if (missing(value)) {
         super$occupancy_mask
       } else {
@@ -203,7 +213,6 @@ DispersalTemplate <- R6Class("DispersalTemplate",
       }
     },
 
-
     #' @field distance_scale Scale of distance values in meters (default = 1). Usage: set to 1 for values in meters, or to 1000 for values in kilometers.
     distance_scale = function(value) {
       if (missing(value)) {
@@ -231,7 +240,12 @@ DispersalTemplate <- R6Class("DispersalTemplate",
       }
     },
 
-    #' @field dispersal_proportion Dispersal function: \emph{p*exp(-distance/b)} \emph{p} parameter. Represents the proportion and limit of dispersers between model cells.
+    #' @field dispersal_proportion Dispersal function:
+    #' \emph{p*exp(-distance/b)} \emph{p} parameter. Represents the proportion
+    #' and limit of dispersers between model cells. This represents a maximum
+    #' potential proportion of dispersers; other factors such as population
+    #' density and carrying capacity may limit the actual proportion of
+    #' dispersers.
     dispersal_proportion = function(value) {
       if (missing(value)) {
         private$.dispersal_proportion
