@@ -35,10 +35,10 @@
 #' @include SpatialModel.R
 #' @export SpatialCorrelation
 
-SpatialCorrelation <- R6Class("SpatialCorrelation",
+SpatialCorrelation <- R6Class(
+  "SpatialCorrelation",
   inherit = SpatialModel,
   public = list(
-
     ## Attributes ##
 
     # object_generator [inherited]
@@ -68,8 +68,12 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
       attribute_aliases <- c(
         attribute_aliases, # Append default aliases
         list(
-          amplitude = "correlation_amplitude", correlation_a = "correlation_amplitude", a = "correlation_amplitude",
-          breadth = "correlation_breadth", correlation_b = "correlation_breadth", b = "correlation_breadth"
+          amplitude = "correlation_amplitude",
+          correlation_a = "correlation_amplitude",
+          a = "correlation_amplitude",
+          breadth = "correlation_breadth",
+          correlation_b = "correlation_breadth",
+          b = "correlation_breadth"
         )
       )
       super$initialize(attribute_aliases = attribute_aliases, ...)
@@ -85,19 +89,39 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
       if (!is.null(self$region)) {
         coordinates <- self$region$coordinates
         if (is.null(coordinates)) {
-          stop("Distance matrix calculation requires the region to be defined with coordinates or a raster first", call. = FALSE)
+          stop(
+            "Distance matrix calculation requires the region to be defined with coordinates or a raster first",
+            call. = FALSE
+          )
         }
-        if (!self$region$use_raster || (is.logical(use_longlat) && use_longlat) ||
-          length(grep("longlat", as.character(raster::crs(self$region$region_raster)), fixed = TRUE)) > 0) {
-          return(earth.dist(coordinates, dist = FALSE)*1000 / self$distance_scale)
-        } else { # assume coordinates in meters
+        if (
+          !self$region$use_raster ||
+            (is.logical(use_longlat) && use_longlat) ||
+            length(grep(
+              "longlat",
+              as.character(raster::crs(self$region$region_raster)),
+              fixed = TRUE
+            )) >
+              0
+        ) {
+          return(
+            earth.dist(coordinates, dist = FALSE) * 1000 / self$distance_scale
+          )
+        } else {
+          # assume coordinates in meters
           if (is.na(raster::crs(self$region$region_raster))) {
-            warning("No coordinate reference system (CRS) specified: assuming coordinates are in meters", call. = FALSE)
+            warning(
+              "No coordinate reference system (CRS) specified: assuming coordinates are in meters",
+              call. = FALSE
+            )
           }
           return(as.matrix(stats::dist(coordinates)) / self$distance_scale)
         }
       } else {
-        stop("Distance matrix calculation requires region to be set first", call. = FALSE)
+        stop(
+          "Distance matrix calculation requires region to be set first",
+          call. = FALSE
+        )
       }
     },
 
@@ -107,7 +131,12 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
     #' @param decimals Optional number of decimal places for correlation values.
     #' @param threshold Optional threshold (minimum value) for correlation values (default 0.0000001).
     #' @param ... Parameters passed via a \emph{params} list or individually.
-    calculate_correlations = function(distance_matrix = NULL, decimals = NULL, threshold = 0.0000001, ...) {
+    calculate_correlations = function(
+      distance_matrix = NULL,
+      decimals = NULL,
+      threshold = 0.0000001,
+      ...
+    ) {
       # Set attributes
       self$correlation_matrix <- NULL
       if (length(list(...))) {
@@ -115,14 +144,28 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
       }
 
       # Ensure region and distance classes are set
-      if (is.null(self$region) || is.null(self$correlation_amplitude) || is.null(self$correlation_breadth)) {
-        stop("Correlation calculations require region and function parameter settings amplitude and breadth", call. = FALSE)
+      if (
+        is.null(self$region) ||
+          is.null(self$correlation_amplitude) ||
+          is.null(self$correlation_breadth)
+      ) {
+        stop(
+          "Correlation calculations require region and function parameter settings amplitude and breadth",
+          call. = FALSE
+        )
       }
 
       # Ensure pre-calculated distance matrix is consistent with region
       if (!is.null(distance_matrix) && !is.null(self$region)) {
-        if (!is.matrix(distance_matrix) || nrow(distance_matrix) != self$region$region_cells || ncol(distance_matrix) != self$region$region_cells) {
-          stop("Distance matrix dimensions must be consistent with the number of region cells", call. = FALSE)
+        if (
+          !is.matrix(distance_matrix) ||
+            nrow(distance_matrix) != self$region$region_cells ||
+            ncol(distance_matrix) != self$region$region_cells
+        ) {
+          stop(
+            "Distance matrix dimensions must be consistent with the number of region cells",
+            call. = FALSE
+          )
         }
       }
 
@@ -132,12 +175,16 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
       }
 
       # Calculate correlation values between each region cell based on a*exp(-distance/b)
-      self$correlation_matrix <- self$correlation_amplitude * exp(-1 * distance_matrix / self$correlation_breadth)
+      self$correlation_matrix <- self$correlation_amplitude *
+        exp(-1 * distance_matrix / self$correlation_breadth)
       diag(self$correlation_matrix) <- 1
 
       # Rounding?
       if (!is.null(decimals)) {
-        self$correlation_matrix <- round(self$correlation_matrix, as.numeric(decimals))
+        self$correlation_matrix <- round(
+          self$correlation_matrix,
+          as.numeric(decimals)
+        )
       } else if (is.numeric(threshold)) {
         self$correlation_matrix[which(self$correlation_matrix < threshold)] <- 0
       }
@@ -149,7 +196,12 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
     #' @param decimals Optional number of decimal places for correlation values.
     #' @param threshold Optional threshold (minimum value) for correlation values (default 0.0000001).
     #' @param ... Parameters passed via a \emph{params} list or individually.
-    calculate_cholesky_decomposition = function(distance_matrix = NULL, decimals = NULL, threshold = 0.0000001, ...) {
+    calculate_cholesky_decomposition = function(
+      distance_matrix = NULL,
+      decimals = NULL,
+      threshold = 0.0000001,
+      ...
+    ) {
       # Set attributes
       self$t_decomposition_matrix <- NULL
       if (length(list(...)) && !is.null(self$correlation_matrix)) {
@@ -158,23 +210,38 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
 
       # Calculate correlations when required
       if (is.null(self$correlation_matrix)) {
-        self$calculate_correlations(distance_matrix = distance_matrix, decimals = decimals, threshold = threshold, ...)
+        self$calculate_correlations(
+          distance_matrix = distance_matrix,
+          decimals = decimals,
+          threshold = threshold,
+          ...
+        )
       }
 
       # Attempt to calculate the transposed Cholesky decomposition matrix
-      self$t_decomposition_matrix <- tryCatch(chol(self$correlation_matrix), error = function(e) e)
+      self$t_decomposition_matrix <- tryCatch(
+        chol(self$correlation_matrix),
+        error = function(e) e
+      )
       if (is.matrix(self$t_decomposition_matrix)) {
-        if (self$compact_only) { # clear the correlation matrix
+        if (self$compact_only) {
+          # clear the correlation matrix
           self$correlation_matrix <- NULL
         }
 
         # Rounding?
         if (!is.null(decimals)) {
-          self$t_decomposition_matrix <- round(self$t_decomposition_matrix, as.numeric(decimals))
+          self$t_decomposition_matrix <- round(
+            self$t_decomposition_matrix,
+            as.numeric(decimals)
+          )
         } else if (is.numeric(threshold)) {
-          self$t_decomposition_matrix[which(self$t_decomposition_matrix < threshold)] <- 0
+          self$t_decomposition_matrix[which(
+            self$t_decomposition_matrix < threshold
+          )] <- 0
         }
-      } else { # assume error caught
+      } else {
+        # assume error caught
 
         error_message <- "for unknown reasons"
         if ("error" %in% class(self$t_decomposition_matrix)) {
@@ -182,7 +249,13 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
         }
         self$t_decomposition_matrix <- NULL
 
-        stop(paste("Cholesky decomposition could not be calculated", error_message), call. = FALSE)
+        stop(
+          paste(
+            "Cholesky decomposition could not be calculated",
+            error_message
+          ),
+          call. = FALSE
+        )
       }
     },
 
@@ -200,33 +273,68 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
 
       # Calculate Cholesky decomposition when required
       if (is.null(self$t_decomposition_matrix)) {
-        self$calculate_cholesky_decomposition(distance_matrix = distance_matrix, ...)
+        self$calculate_cholesky_decomposition(
+          distance_matrix = distance_matrix,
+          ...
+        )
       }
 
       # Calculate non-zero decomposition data from the decomposition matrix
-      t_decomposition_data <- which(self$t_decomposition_matrix != 0, arr.ind = TRUE, useNames = TRUE)
-      t_decomposition_data <- as.data.frame(cbind(t_decomposition_data, self$t_decomposition_matrix[t_decomposition_data]))
+      t_decomposition_data <- which(
+        self$t_decomposition_matrix != 0,
+        arr.ind = TRUE,
+        useNames = TRUE
+      )
+      t_decomposition_data <- as.data.frame(cbind(
+        t_decomposition_data,
+        self$t_decomposition_matrix[t_decomposition_data]
+      ))
       region_cells <- nrow(self$t_decomposition_matrix)
-      if (self$compact_only) { # clear the full decomposition matrix
+      if (self$compact_only) {
+        # clear the full decomposition matrix
         self$t_decomposition_matrix <- NULL
       }
       names(t_decomposition_data) <- c("row", "col", "value")
-      t_decomposition_data <- t_decomposition_data[order(t_decomposition_data$col, t_decomposition_data$row), ]
+      t_decomposition_data <- t_decomposition_data[
+        order(t_decomposition_data$col, t_decomposition_data$row),
+      ]
 
       # Create a compact transposed decomposition matrix
       if (!is.null(self$region)) {
         region_cells <- self$region$region_cells # should be same as rows/columns in full matrix
       }
-      t_decomposition_nonzero_rows <- tabulate(t_decomposition_data$col, nbins = region_cells)
+      t_decomposition_nonzero_rows <- tabulate(
+        t_decomposition_data$col,
+        nbins = region_cells
+      )
       t_decomposition_compact_rows <- max(t_decomposition_nonzero_rows)
-      self$t_decomposition_compact_matrix <- array(1:t_decomposition_compact_rows, c(t_decomposition_compact_rows, region_cells))
-      self$t_decomposition_compact_matrix <- self$t_decomposition_compact_matrix * (self$t_decomposition_compact_matrix <= matrix(t_decomposition_nonzero_rows, nrow = t_decomposition_compact_rows, ncol = region_cells, byrow = TRUE))
-      t_decomposition_compact_indices <- which(self$t_decomposition_compact_matrix != 0)
-      self$t_decomposition_compact_matrix[t_decomposition_compact_indices] <- t_decomposition_data$value
+      self$t_decomposition_compact_matrix <- array(
+        1:t_decomposition_compact_rows,
+        c(t_decomposition_compact_rows, region_cells)
+      )
+      self$t_decomposition_compact_matrix <- self$t_decomposition_compact_matrix *
+        (self$t_decomposition_compact_matrix <=
+          matrix(
+            t_decomposition_nonzero_rows,
+            nrow = t_decomposition_compact_rows,
+            ncol = region_cells,
+            byrow = TRUE
+          ))
+      t_decomposition_compact_indices <- which(
+        self$t_decomposition_compact_matrix != 0
+      )
+      self$t_decomposition_compact_matrix[
+        t_decomposition_compact_indices
+      ] <- t_decomposition_data$value
 
       # Create a map to the original region grid rows
-      self$t_decomposition_compact_map <- array(NA, c(t_decomposition_compact_rows, region_cells))
-      self$t_decomposition_compact_map[t_decomposition_compact_indices] <- t_decomposition_data$row
+      self$t_decomposition_compact_map <- array(
+        NA,
+        c(t_decomposition_compact_rows, region_cells)
+      )
+      self$t_decomposition_compact_map[
+        t_decomposition_compact_indices
+      ] <- t_decomposition_data$row
     },
 
     #' @description
@@ -236,14 +344,25 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
     #' @return List containing a compact Cholesky decomposition matrix and a corresponding map of region cell indices (for the compacted rows).
     get_compact_decomposition = function(distance_matrix = NULL, ...) {
       # Calculate compact decomposition when required
-      if (!is.null(distance_matrix) || is.null(self$t_decomposition_compact_matrix) || is.null(self$t_decomposition_compact_map)) {
-        self$calculate_compact_decomposition(distance_matrix = distance_matrix, ...)
-      } else if (length(list(...))) { # set attributes
+      if (
+        !is.null(distance_matrix) ||
+          is.null(self$t_decomposition_compact_matrix) ||
+          is.null(self$t_decomposition_compact_map)
+      ) {
+        self$calculate_compact_decomposition(
+          distance_matrix = distance_matrix,
+          ...
+        )
+      } else if (length(list(...))) {
+        # set attributes
         self$set_attributes(...)
       }
 
       # Pack the decomposition compact matrix and map into a list
-      return(list(matrix = self$t_decomposition_compact_matrix, map = self$t_decomposition_compact_map))
+      return(list(
+        matrix = self$t_decomposition_compact_matrix,
+        map = self$t_decomposition_compact_map
+      ))
     },
 
     #' @description
@@ -252,10 +371,19 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
     #' @param temporal_correlation Optional temporal correlation coefficient (0-1; default = 1).
     #' @param time_steps Optional number of time steps for temporal correlation (default = 1 or none).
     #' @return Array (non-temporal) or matrix (temporal) of correlated normal deviates.
-    generate_correlated_normal_deviates = function(random_seed = NULL, temporal_correlation = 1, time_steps = 1) {
+    generate_correlated_normal_deviates = function(
+      random_seed = NULL,
+      temporal_correlation = 1,
+      time_steps = 1
+    ) {
       # Ensure compact correlation decomposition is calculated
-      if (is.null(self$t_decomposition_compact_matrix) || is.null(self$t_decomposition_compact_map)) {
-        return("The compact correlation decomposition needs to be calculated before correlated normal deviates can be generated")
+      if (
+        is.null(self$t_decomposition_compact_matrix) ||
+          is.null(self$t_decomposition_compact_map)
+      ) {
+        return(
+          "The compact correlation decomposition needs to be calculated before correlated normal deviates can be generated"
+        )
       }
 
       # Resolve dimensions
@@ -270,45 +398,68 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
       # Generate temporal deviates
       if (time_steps > 1) {
         if (temporal_correlation < 1) {
-          deviates <- array(stats::rnorm(region_cells * time_steps), c(region_cells, time_steps))
+          deviates <- array(
+            stats::rnorm(region_cells * time_steps),
+            c(region_cells, time_steps)
+          )
           # Calculate a Cholesky decomposition for temporal correlation between sequential time-steps
           if (temporal_correlation > 0) {
             time_step_correlation <- array(temporal_correlation, c(2, 2))
             diag(time_step_correlation) <- 1
             time_step_decomposition <- chol(time_step_correlation)[, 2]
             for (i in 2:time_steps) {
-              deviates[, i] <- time_step_decomposition[1] * deviates[, i - 1] + time_step_decomposition[2] * deviates[, i]
+              deviates[, i] <- time_step_decomposition[1] *
+                deviates[, i - 1] +
+                time_step_decomposition[2] * deviates[, i]
             }
           }
-        } else { # temporal correlation = 1 : duplicate deviates across time
-          deviates <- array(stats::rnorm(region_cells), c(region_cells, time_steps))
+        } else {
+          # temporal correlation = 1 : duplicate deviates across time
+          deviates <- array(
+            stats::rnorm(region_cells),
+            c(region_cells, time_steps)
+          )
         }
 
         # Apply spatial correlation to the temporal deviates
         for (i in 1:time_steps) {
-          deviates[, i] <- .colSums(self$t_decomposition_compact_matrix * deviates[self$t_decomposition_compact_map, i],
-            m = compact_rows, n = region_cells, na.rm = TRUE
+          deviates[, i] <- .colSums(
+            self$t_decomposition_compact_matrix *
+              deviates[self$t_decomposition_compact_map, i],
+            m = compact_rows,
+            n = region_cells,
+            na.rm = TRUE
           )
         }
 
         return(deviates)
-      } else { # Generate spatially correlated only
+      } else {
+        # Generate spatially correlated only
 
-        return(.colSums(self$t_decomposition_compact_matrix * stats::rnorm(region_cells)[self$t_decomposition_compact_map],
-          m = compact_rows, n = region_cells, na.rm = TRUE
+        return(.colSums(
+          self$t_decomposition_compact_matrix *
+            stats::rnorm(region_cells)[self$t_decomposition_compact_map],
+          m = compact_rows,
+          n = region_cells,
+          na.rm = TRUE
         ))
       }
     }
   ), # end public
 
   private = list(
-
     ## Attributes ##
 
     # Model attributes #
     .model_attributes = c(
-      "region", "distance_scale", "correlation_amplitude", "correlation_breadth", "correlation_matrix",
-      "t_decomposition_matrix", "compact_only", "t_decomposition_compact_matrix",
+      "region",
+      "distance_scale",
+      "correlation_amplitude",
+      "correlation_breadth",
+      "correlation_matrix",
+      "t_decomposition_matrix",
+      "compact_only",
+      "t_decomposition_compact_matrix",
       "t_decomposition_compact_map"
     ),
     # .region            [inherited]
@@ -323,8 +474,15 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
 
     # Attributes accessible via model get/set methods #
     .active_attributes = c(
-      "region", "distance_scale", "coordinates", "correlation_amplitude", "correlation_breadth",
-      "correlation_matrix", "t_decomposition_matrix", "compact_only", "t_decomposition_compact_matrix",
+      "region",
+      "distance_scale",
+      "coordinates",
+      "correlation_amplitude",
+      "correlation_breadth",
+      "correlation_matrix",
+      "t_decomposition_matrix",
+      "compact_only",
+      "t_decomposition_compact_matrix",
       "t_decomposition_compact_map"
     )
 
@@ -338,11 +496,11 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
 
   # Active binding accessors for private attributes (above) #
   active = list(
-
     # Model attribute accessors #
 
     #' @field model_attributes A vector of model attribute names.
-    model_attributes = function(value) { # inherited
+    model_attributes = function(value) {
+      # inherited
       if (missing(value)) {
         super$model_attributes
       } else {
@@ -355,16 +513,32 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
       if (missing(value)) {
         private$.region
       } else {
-        if (!is.null(self$correlation_matrix) || !is.null(self$t_decomposition_matrix) ||
-          !is.null(self$t_decomposition_compact_matrix) || !is.null(self$t_decomposition_compact_map)) {
-          stop("Calculated correlations/decompositions are already associated with the existing region", call. = FALSE)
+        if (
+          !is.null(self$correlation_matrix) ||
+            !is.null(self$t_decomposition_matrix) ||
+            !is.null(self$t_decomposition_compact_matrix) ||
+            !is.null(self$t_decomposition_compact_map)
+        ) {
+          stop(
+            "Calculated correlations/decompositions are already associated with the existing region",
+            call. = FALSE
+          )
         } else {
           if ("Region" %in% class(value)) {
-            if ((value$use_raster && is.null(value$region_raster)) || (!value$use_raster && is.null(value$coordinates))) {
-              warning("Spatial region has not been defined within the region object", call. = FALSE)
+            if (
+              (value$use_raster && is.null(value$region_raster)) ||
+                (!value$use_raster && is.null(value$coordinates))
+            ) {
+              warning(
+                "Spatial region has not been defined within the region object",
+                call. = FALSE
+              )
             }
           } else if (!is.null(value)) {
-            stop("Region should be a Region (or inherited class) object", call. = FALSE)
+            stop(
+              "Region should be a Region (or inherited class) object",
+              call. = FALSE
+            )
           }
           private$.region <- value
         }
@@ -372,7 +546,8 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
     },
 
     #' @field coordinates Data frame (or matrix) of X-Y population (WGS84) coordinates in longitude (degrees West) and latitude (degrees North) (get and set), or distance-based coordinates dynamically returned by region raster (get only).
-    coordinates = function(value) { # inherited
+    coordinates = function(value) {
+      # inherited
       if (missing(value)) {
         super$coordinates
       } else {
@@ -394,13 +569,28 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
       if (missing(value)) {
         private$.correlation_amplitude
       } else {
-        if (!is.null(self$correlation_matrix) || !is.null(self$t_decomposition_matrix) ||
-          !is.null(self$t_decomposition_compact_matrix) || !is.null(self$t_decomposition_compact_map)) {
-          stop("Calculated correlations/decompositions are already associated with the existing correlation parameters", call. = FALSE)
-        } else if (!is.null(value) && is.numeric(value) && (value > 1 || value < 0)) {
-          stop("Correlation function parameter amplitude must be between 0 and 1 inclusively", call. = FALSE)
+        if (
+          !is.null(self$correlation_matrix) ||
+            !is.null(self$t_decomposition_matrix) ||
+            !is.null(self$t_decomposition_compact_matrix) ||
+            !is.null(self$t_decomposition_compact_map)
+        ) {
+          stop(
+            "Calculated correlations/decompositions are already associated with the existing correlation parameters",
+            call. = FALSE
+          )
+        } else if (
+          !is.null(value) && is.numeric(value) && (value > 1 || value < 0)
+        ) {
+          stop(
+            "Correlation function parameter amplitude must be between 0 and 1 inclusively",
+            call. = FALSE
+          )
         } else if (!is.null(value) && !is.numeric(value)) {
-          stop("Correlation function parameter amplitude must be numeric", call. = FALSE)
+          stop(
+            "Correlation function parameter amplitude must be numeric",
+            call. = FALSE
+          )
         } else {
           private$.correlation_amplitude <- value
         }
@@ -412,13 +602,26 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
       if (missing(value)) {
         private$.correlation_breadth
       } else {
-        if (!is.null(self$correlation_matrix) || !is.null(self$t_decomposition_matrix) ||
-          !is.null(self$t_decomposition_compact_matrix) || !is.null(self$t_decomposition_compact_map)) {
-          stop("Calculated correlations/decompositions are already associated with the existing correlation parameters", call. = FALSE)
+        if (
+          !is.null(self$correlation_matrix) ||
+            !is.null(self$t_decomposition_matrix) ||
+            !is.null(self$t_decomposition_compact_matrix) ||
+            !is.null(self$t_decomposition_compact_map)
+        ) {
+          stop(
+            "Calculated correlations/decompositions are already associated with the existing correlation parameters",
+            call. = FALSE
+          )
         } else if (!is.null(value) && is.numeric(value) && value <= 0) {
-          stop("Correlation function parameter breadth must be positive/non-zero", call. = FALSE)
+          stop(
+            "Correlation function parameter breadth must be positive/non-zero",
+            call. = FALSE
+          )
         } else if (!is.null(value) && !is.numeric(value)) {
-          stop("Correlation function parameter breadth must be numeric", call. = FALSE)
+          stop(
+            "Correlation function parameter breadth must be numeric",
+            call. = FALSE
+          )
         } else {
           private$.correlation_breadth <- value
         }
@@ -473,7 +676,8 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
     # Dynamic attribute accessors #
 
     #' @field attribute_aliases A list of alternative alias names for model attributes (form: \code{alias = "attribute"}) to be used with the set and get attributes methods.
-    attribute_aliases = function(value) { # inherited
+    attribute_aliases = function(value) {
+      # inherited
       if (missing(value)) {
         super$attribute_aliases
       } else {
@@ -484,7 +688,8 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
     # Errors and warnings accessors #
 
     #' @field error_messages A vector of error messages encountered when setting model attributes.
-    error_messages = function(value) { # inherited
+    error_messages = function(value) {
+      # inherited
       if (missing(value)) {
         super$error_messages
       } else {
@@ -493,7 +698,8 @@ SpatialCorrelation <- R6Class("SpatialCorrelation",
     },
 
     #' @field warning_messages A vector of warning messages encountered when setting model attributes.
-    warning_messages = function(value) { # inherited
+    warning_messages = function(value) {
+      # inherited
       if (missing(value)) {
         super$warning_messages
       } else {
