@@ -1,3 +1,3 @@
-test_function = function (params) {
+test_function <- function(params) {
   return(params[[1]] + params[[2]])
 }
